@@ -433,10 +433,18 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
                 else:
                     dataframe = df.copy()
 
-        dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
+        dataframe['TimeTo'] = pd.to_datetime(dataframe['TimeTo'], unit='s')
+        dataframe['TimeFrom'] = pd.to_datetime(dataframe['TimeFrom'], unit='s')
+        data_df = pd.DataFrame.from_records(dataframe['Data'])
+        data_df.index = dataframe.index
+
+        dataframe = pd.merge(dataframe, data_df, left_index=True, right_index=True)
+
         dataframe = dataframe.sort_values(by=['time'])
+        dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
         dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
         dataframe = dataframe.set_index(dataframe['date'])
+
         dataframe = dataframe.drop(columns=['date','volumefrom', 'conversionType', 'conversionSymbol' ])
 
         dataframe = dataframe.rename(columns ={'volumeto':'volume'})
